@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ob-deno" "3.0.0"
+(define-package "ob-deno" "20250913.1628"
   "Babel Functions for Javascript/TypeScript with Deno."
   '((emacs "29.1"))
   :url "https://github.com/isamert/ob-deno"
